﻿using System;
namespace ObjectCache.Ejm1
{
    /// <summary>
    /// Esta clase es la responsable de la gestión de todos los items. 
    /// Tiene el método activate que permite a otros objetos de la aplicación activar un item
    /// </summary>
    public class ItemManager
    {
        ItemCache Cache;
        DBManager Manager;

        public ItemManager()
        {
            Cache = new ItemCache();
            Manager = new DBManager();
        }
        /// <summary>
        /// ItemManager verifica si el item ya existe en el caché. Si el objeto ya existe, esto signfica
        /// que el objeto ya ha sido activado recientemente. ItemManager simplemente retorna el mensaje
        /// apropiado. Si el item no existe, entonces ItemManager accede a la base de datos utilizando una
        /// clase helper DBManager para verificar si el item está activo en la base de datos. 
        /// Si el item ya está activado en la base de datos, retorna el mensaje apropiado. 
        /// Si no, ItemManager actualiza el item como activo, le establece la fecha de activación y 
        /// adiciona el item al caché. 
        /// </summary>
        /// <param name="code">Codigo de barras el articulo</param>
        public void Activate(String code)
        {
            if (Cache.GetItem(code) != null)
            {
                Console.WriteLine("Item Already Activated - cache");
            }
            else
            {
                if (Manager.IsActiveItem(code))
                {
                    Console.WriteLine("Item Already Activated - DB Access");
                }
                else
                {
                    Manager.ActivateItem(code);
                    Console.WriteLine("Item Activated successfully");
                    //add to the cache
                    Cache.AddItem(code);
                }
            }
        }
    }
}
